Add-PSSnapin Microsoft.SharePoint.Powershell

function GetAllWebs($url)
{
   CreateSiteColumns $w;
    try
    {
        Write-Host ([String]::Format("Procesing web {0}",$w.Url)) -foregroundcolor Blue
        if($w.Webs.Count -gt 0)
        {
            foreach($web in $w.Webs)
            {
	            UpdateRDCCalendar $web
                CreateSRSCalendar $web
                UpdateIACUCCalendar $web                 
                UpdateSRSCalendarView $web;
                UpdateEnvironmentView $web;
	        }
       }
      
    }
    catch
    {
        Write-Host ([String]::Format("Error processing web at $url, with Exception: {0}", $_.Exception.Message)) -foregroundcolor Red
    }   
}

function DeleteSRSCalendar($web) 
{
  $list = $web.Lists.TryGetList("SRS Calendar")
    if($list -ne $null)
    {
        # The list already exists
        $ListToDeleteName = "SRS Calendar"
	    echo "Deleting List"   $ListToDeleteName
 
	    #Get Web and List objects
	    $list = $web.Lists[$ListToDeleteName]
	
	    #Reset the "Allow Deletion" Flag
	    $list.AllowDeletion = $true
       
	    $list.Update()
	    $list.Delete()
    }	


}

function CreateSiteColumns ($web) {

    write-Host "Creating Site Columns" -foregroundcolor blue       
    if (!$web.Fields.ContainsFieldWithStaticName("EventCommitteeAttendees")){
    	$sFieldDisplayName="Committee Attendees" 
		$sFieldInternalName="EventCommitteeAttendees" 
		$sFieldType="User" 
		
        write-Host "Adding the field $sFieldDisplayName to the Site" -foregroundcolor blue             
		$web.Fields.Add($sFieldInternalName,$sFieldType,$false) 
		$spField=$web.Fields.GetField($sFieldInternalName) 
		$spField.Group="RAMS IRB" 
		$spField.Title=$sFieldDisplayName 
		$spField.SelectionMode = "PeopleAndGroups"
        $spField.SelectionGroup="0"
	    $spField.LookupField="ImnName"
	    $spField.AllowMultipleValues = $true
	    
		$spField.Update()  
    }
    
     if (!$web.Fields.ContainsFieldWithStaticName("EventAttendees")){
    	$sFieldDisplayName="Attendees" 
		$sFieldInternalName="EventAttendees" 
		$sFieldType="User" 
		
        write-Host "Adding the field $sFieldDisplayName to the Site" -foregroundcolor blue             
		$web.Fields.Add($sFieldInternalName,$sFieldType,$false) 
		$spField=$web.Fields.GetField($sFieldInternalName) 
		$spField.Group="RAMS IRB" 
		$spField.Title=$sFieldDisplayName 
		$spField.SelectionMode = "PeopleAndGroups";
        $spField.SelectionGroup = "0"
	    $spField.LookupField="ImnName"
	    $spField.AllowMultipleValues = $true
	    
		$spField.Update()  
    }
    
    if (!$web.Fields.ContainsFieldWithStaticName("EventDecision")){
    	$sFieldDisplayName="Decision" 
		$sFieldInternalName="EventDecision" 
		$sFieldType="Note" 
		
        write-Host "Adding the field $sFieldDisplayName to the Site" -foregroundcolor blue             
		$web.Fields.Add($sFieldInternalName,$sFieldType,$false) 
		$spField=$web.Fields.GetField($sFieldInternalName) 
		$spField.Group="RAMS IRB" 
		$spField.Title=$sFieldDisplayName 
		
		$spField.Update()  

    }
    
    if (!$web.Fields.ContainsFieldWithStaticName("EventDeliberation")){
    	$sFieldDisplayName="Deliberation" 
		$sFieldInternalName="EventDeliberation" 
		$sFieldType="Note" 
		
        write-Host "Adding the field $sFieldDisplayName to the Site" -foregroundcolor blue             
		$web.Fields.Add($sFieldInternalName,$sFieldType,$false) 
		$spField=$web.Fields.GetField($sFieldInternalName) 
		$spField.Group="RAMS IRB" 
		$spField.Title=$sFieldDisplayName 
		
		$spField.Update()  
    }
	
	 if (!$web.Fields.ContainsFieldWithStaticName("EventAdministrativeItems")){
		$sFieldDisplayName="Administrative Items" 
		$sFieldInternalName="EventAdministrativeItems" 
		$sFieldType="Note" 
		
        write-Host "Adding the field $sFieldDisplayName to the Site" -foregroundcolor blue             
		$web.Fields.Add($sFieldInternalName,$sFieldType,$false) 
		$spField=$web.Fields.GetField($sFieldInternalName) 
		$spField.Group="RAMS IRB" 
		$spField.Title=$sFieldDisplayName 
		
		$spField.Update()  
    	
    }
 
    $contentType = "Event"
    $ct = $web.ContentTypes[$contentType]

   #ADD SITE COLUMNS TO CONTENT TYPE
   echo "ADDING SITECOLUMNS TO CONTENT TYPE"

  if($web.ContentTypes["Event"] -ne $null){
	
    if(!$ct.Fields.ContainsField("Committee Attendees")){
		$field = $web.Fields["Committee Attendees"]
		
		$link = new-object Microsoft.SharePoint.SPFieldLink $field
		
		$ct.FieldLinks.Add($link)
		
		$ct.Update($false)
	}
	
	if(!$ct.Fields.ContainsField("Attendees")){
		$field = $web.Fields["Attendees"]
		
		$link = new-object Microsoft.SharePoint.SPFieldLink $field
		
		$ct.FieldLinks.Add($link)
		
		$ct.Update($false)
	}
	
	if(!$ct.Fields.ContainsField("Decision")){
		$field = $web.Fields["Decision"]
		
		$link = new-object Microsoft.SharePoint.SPFieldLink $field
		
		$ct.FieldLinks.Add($link)
		
		$ct.Update($false)
	}
	
	if(!$ct.Fields.ContainsField("Deliberation")){
		$field = $web.Fields["Deliberation"]
		
		$link = new-object Microsoft.SharePoint.SPFieldLink $field
		
		$ct.FieldLinks.Add($link)
		
		$ct.Update($false)
	}
	
	if(!$ct.Fields.ContainsField("Administrative Items")){
		$field = $web.Fields["Administrative Items"]
		
		$link = new-object Microsoft.SharePoint.SPFieldLink $field
		
		$ct.FieldLinks.Add($link)
		
		$ct.Update($false)
	}
	
	if(!$ct.Fields.ContainsField("Enterprise Keywords")){
		$field = $web.Fields["Enterprise Keywords"]
		
		$link = new-object Microsoft.SharePoint.SPFieldLink $field
		
		$ct.FieldLinks.Add($link)
		
		$ct.Update($false)
	}

	if(!$ct.Fields.ContainsField("Enterprise Keywords")){
		$field = $web.Fields["Enterprise Keywords"]
		
		$link = new-object Microsoft.SharePoint.SPFieldLink $field
		
		$ct.FieldLinks.Add($link)
		
		$ct.Update($false)
	}
	}
	
}


function CreateSRSCalendar($web) 
{  
        echo "This SRS Is created" $web.url
        $SPTemplate = $w.ListTemplates["Calendar"]
        $web.Lists.Add("SRSCalendar","SRSCalendar",$SPTemplate)
        $list = $web.Lists.TryGetList("SRSCalendar")
       
        if($list -ne $null)
        {
            $list.Title="SRS Calendar";
            $list.Update()
            
            $spField=$web.Fields.GetField("SubmittedApplicationLookup") 
		    if ($spField -ne $null) 
		    {
		    	$list.Fields.Add($spField);
                $list.Update() 
    		}
        }
}

function UpdateIACUCCalendar($web) 
{  
   echo "This IACUC Is created" $web.url
   $list = $web.Lists.TryGetList("IACUC Calendar")       
    if($list -ne $null)
    {
                   
        $spField=$web.Fields.GetField("SubmittedApplicationLookup") 
		if ($spField -ne $null) 
		{
		    $list.Fields.Add($spField);
            $list.Update() 
		}
        
    }
 }
function UpdateRDCCalendar($web) 
{  
   echo "This RDC Is approved" $web.url
   $list = $web.Lists.TryGetList("RDC Calendar")       
    if($list -ne $null)
    {
                   
        $spField=$web.Fields.GetField("ApprovedApplicationsLookup") 
		if ($spField -ne $null) 
		{
		    $list.Fields.Add($spField);
            $list.Update() 
		}
        
    }
 }

function  UpdateSRSCalendarView($web) 
{
 
    $list = $web.Lists.TryGetList("SRS Calendar")
    if($list -ne $null)
    {
      #UPDATE THE VIEW
      echo "UPDATING THE VIEW"
      $view = $list.Views | ? { $_.Title -eq 'All Events' };
 	
 	    if( $view.ViewFields.exists("Location")){
       		$view.ViewFields.Delete("Location");
       	}

     
       if( $view.ViewFields.exists("EventDate")){
      	$view.ViewFields.Delete("EventDate");
       }

	  if( $view.ViewFields.exists("EndDate")){
        $view.ViewFields.Delete("EndDate");
       }
       
       if( $view.ViewFields.exists("fAllDayEvent")){
        $view.ViewFields.Delete("fAllDayEvent");
       
       }

	   #Create customized view
	   if( !$view.ViewFields.exists("EventDate")){
        $view.ViewFields.Add("EventDate"); 
       }
       
  	   if( !$view.ViewFields.exists("EndDate")){
        $view.ViewFields.Add("EndDate"); 
       }
       
      if( !$view.ViewFields.exists("Location")){
        $view.ViewFields.Add("Location"); 
       }
	
	  if( !$view.ViewFields.exists("Attendees")){
        $view.ViewFields.Add("Attendees"); 
       }
       
       if( !$view.ViewFields.exists("Committee Attendees")){
        $view.ViewFields.Add("Committee Attendees"); 
       }
  
        $view.DefaultView = $true
        $view.Update()

        if($list -ne $null)
        {
     
            $contentType = "Event"
            $newFieldOrder = @("Title", "EventDate", "EndDate", "Location", "fAllDayEvent", "fRecurrence","EventCommitteeAttendees",  "ParticipantsPicker","Administrative_x0020_Items", "TaxKeyword", "ApprovedApplicationLookup", "SRSMeetingMinuteLookup", "Decision", 
            "Deliberation"
            )
           if ($list.Fields.ContainsField("Description")) {
	            $ct = $list.ContentTypes[$contentType] 
	            $ct.FieldLinks["Description"].Hidden = $True
	            $ct.FieldLinks.Reorder($newFieldOrder)
	            $ct.Update() 
	            $list.Update()
           }

          if ($list.Fields.ContainsField("Category")) {
	            $categoryfield=$list.Fields["Category"]
	            $categoryfield.ShowInNewForm=$false 
	            $categoryfield.ShowInEditForm=$false
	            $categoryfield.Update($true)
	            $list.Update()
       	 }
       
      	  if ($list.Fields.ContainsField("ApplicationsLookup")) {
      		$applicationsField=$list.Fields["ApplicationsLookup"]
            $applicationsField.ShowInNewForm=$false 
            $applicationsField.ShowInEditForm=$false
            $applicationsField.Update($true)
            $list.Update()
      	  }
      	  
      	  if ($list.Fields.ContainsField("ApprovedRDCApplicationLookup")) {
      	    $approvedRDCApplicationLookup=$list.Fields["ApprovedRDCApplicationLookup"]
            $approvedRDCApplicationLookup.ShowInNewForm=$false 
            $approvedRDCApplicationLookup.ShowInEditForm=$false
            $approvedRDCApplicationLookup.Update($true)
            $list.Update()
      	  }

          if ($list.Fields.ContainsField("ApprovedApplicationsLookup")) {
      		$applicationsField=$list.Fields["ApprovedApplicationsLookup"]
            $applicationsField.ShowInNewForm=$false 
            $applicationsField.ShowInEditForm=$false
            $applicationsField.Update($true)
            $list.Update()
      	  }
        }	

    }	
}    
   
function  UpdateEnvironmentView($web) 
{
 
    $list = $web.Lists.TryGetList("Environment")
    if($list -ne $null)
    {
	   $spFieldType = "Text"
       $list.Fields.Add("Site",$spFieldType,$true)
       $list.Update();

        #Get all items in this list and save them to a variable
        $items = $list.items

        #Go through all items
        foreach($item in $items)
        {
    
	        #Change the value of the "Title" column
	        $item["Site"] = $web.Title
	
	        #Update the item
	        $item.Update()
    }	

    }
}

#This is to test the driver contains a $siteUrl
#$siteUrl="https://vaww.idev.ram.msp.va.gov/sites/IRBApplications/";
$w = Get-SPWeb $siteUrl;
GetAllWebs($siteUrl)