Add-PSSnapin Microsoft.SharePoint.Powershell

function GetAllWebs($url)
{
    #try
    #{
        Write-Host ([String]::Format("Procesing web {0}",$w.Url)) -foregroundcolor Blue
    
        if($w.Webs.Count -gt 0)
        {
            foreach($web in $w.Webs)
            {
               CreateApplicationLookupSiteColumn $web;
               CreateSubmittedCalculatedField $web;
               CreateSubmittedSiteColumn $web;
               CreateApprovedCalculatedField $web;
               CreateApprovedSiteColumn $web;
             }
        }
    #}
    #catch
    #{
    #    Write-Host ([String]::Format("Error processing web at $url, with Exception: {0}", $_.Exception.Message)) -foregroundcolor Red
    #}   
}


function CreateApplicationLookupSiteColumn ($web) {
 	#CREATE SITE COLUMNS
    echo "CREATING SITE COLUMNS"
    
	# GET THE LISTS
	$myList = $web.Lists["ApplicationFacilityLookup"];

	#Where the Source List for Lookup Exists
	
	$ParentWebURL=$web.Url
	$ParentListName="ApplicationFacilityLookup"
	$ParentLookupColumnName="Study Title"
	
	
	#Where the Lookup Site column Going to get created
	$ChildWebURL=$web.Url
	$ChildLookupColumnName="ApplicationsLookup"
	
	#Get the Parent and Child Webs and List
	
	$ParentWeb = Get-SPWeb $ParentWebURL
	$ParentList = $ParentWeb.Lists[$ParentListName]
	$ChildWeb = Get-SPWeb $ChildWebURL
	
	if(!$ChildWeb.Fields.ContainsField($ChildLookupColumnName))
	{
	    #Add Lookup Field
	
	    $ChildLookupColumn = $ChildWeb.Fields.AddLookup($ChildLookupColumnName,$ParentList.id,$False)
	    $ChildWeb.Update()

	    $ChildLookupColumn = $ChildWeb.Fields[$ChildLookupColumnName]
	
	    #Setup lookup Field property
	
	    $ChildLookupColumn.LookupWebId = $ParentWeb.ID
	
	    $ChildLookupColumn.LookupField = $ParentList.Fields[$ParentLookupColumnName].InternalName
	
	    $ChildLookupColumn.AllowMultipleValues=$true
	
	   	$ChildLookupColumn.Group="RAMS IRB" 
        $ChildLookupColumn.Title="Application Lookup"

	    $ChildLookupColumn.update()
	
	    write-host "Lookup field added successfully!" -f green
	  
		#CREATE LIST COLUMNS FROM SITE COLUMNS
		echo "CREATING LIST COLUMNS"
		
	    $calendarName="Committee Calendar"
		
	    # GET THE LISTS
		$myList = $web.Lists[$calendarName];
		
	    if (!$myList.Fields.ContainsField("Application Lookup")) {
	        write-host "Add to Committee Calendar" -f green
            if($web.Fields.TryGetFieldByStaticName($ChildLookupColumnName) -ne $null)
            {
			    $listField=$web.Fields.GetFieldByInternalName($ChildLookupColumnName)
			    $myList.Fields.Add($listField)
			    $myList.Update()
            }
            else
            {
                Write-Host "Site Column: $ChildLookupColumnName  Does not exist" 
            }
		}
	
	}
	else
	{
	    write-host "Field Exists already!" -f red
	} 
	

	
}

function CreateSubmittedCalculatedField ($web) {

	#Variables
	$ListName="ApplicationFacilityLookup"
	$CalculatedColumnName="SubmittedApplications"
	
	#Get the List
	$list = $web.Lists.TryGetList($ListName)
	  
	
	if ($list -ne $null) {
		if (!$list.Fields.ContainsFieldWithStaticName("SubmittedApplications")) {
			#Add new calculated column
			$list.Fields.Add($CalculatedColumnName, "Calculated", $false)
			$list.Update() 
			#Get the column
			$CalculatedCol = $List.Fields.GetField($CalculatedColumnName)
			#Set Formula for calculated column 
	        $CalculatedCol.Formula="=IF(AND([Application Status]=""Submitted"", [MovedToFacility]=""""), [Study Title], """")"
			$CalculatedCol.OutputType="Text"
			$CalculatedCol.Title="Submitted Applications"
			$CalculatedCol.Update()
		}
	}

}

function CreateSubmittedSiteColumn ($web) {
 	#CREATE SITE COLUMNS
    echo "CREATING SITE COLUMNS"
    
	# GET THE LISTS
	$myList = $web.Lists["ApplicationFacilityLookup"];

	#Where the Source List for Lookup Exists
	
	$ParentWebURL=$web.Url
	$ParentListName="ApplicationFacilityLookup"
	$ParentLookupColumnName="Submitted Applications"
	
	#Where the Lookup Site column Going to get created
	$ChildWebURL=$web.Url
	$ChildLookupColumnName="SubmittedApplicationLookup"
	
	#Get the Parent and Child Webs and List
	
	$ParentWeb = Get-SPWeb $ParentWebURL
	$ParentList = $ParentWeb.Lists[$ParentListName]
	$ChildWeb = Get-SPWeb $ChildWebURL
	
	if(!$ChildWeb.Fields.ContainsField($ChildLookupColumnName))
	{
	    #Add Lookup Field
	
	    $ChildLookupColumn = $ChildWeb.Fields.AddLookup($ChildLookupColumnName,$ParentList.id,$False)
	
        $ChildWeb.Update()
           
	    $ChildLookupColumn = $ChildWeb.Fields[$ChildLookupColumnName]

    
	
	    #Setup lookup Field property
	
	    $ChildLookupColumn.LookupWebId = $ParentWeb.ID
	
	    $ChildLookupColumn.LookupField = $ParentList.Fields[$ParentLookupColumnName].InternalName
	
	    $ChildLookupColumn.AllowMultipleValues=$true
	
	   	$ChildLookupColumn.Group="RAMS IRB" 
        $ChildLookupColumn.Title="Submitted Application Lookup"

	    $ChildLookupColumn.update()
	
	    write-host "Lookup field added successfully!" -f green
	    
	    #CREATE LIST COLUMNS FROM SITE COLUMNS
		echo "CREATING LIST COLUMNS"
	
	    $calendarName="IACUC Calendar"
		
	    # GET THE LISTS
		$myList = $web.Lists[$calendarName];
		
		if ($myList -ne $null) {
			if (!$myList.Fields.ContainsFieldWithStaticName("SubmittedApplicationLookup")) {
            if($web.Fields.TryGetFieldByStaticName($ChildLookupColumnName) -ne $null)
            {
			    $listField=$web.Fields.GetFieldByInternalName($ChildLookupColumnName)
			    $myList.Fields.Add($listField)
			    $myList.Update()
            }
            else
            {
                Write-Host "Site Column: $ChildLookupColumnName  , $web.Url, $myList.Title, Does not exist" 
            }
  		 }
		}
		
		$calendarName="SRS Calendar"
		
	    # GET THE LISTS
		$myList = $web.Lists[$calendarName];
		if ($myList -ne $null) {
		  if (!$myList.Fields.ContainsFieldWithStaticName("SubmittedApplicationLookup")) {
            if($web.Fields.TryGetFieldByStaticName($ChildLookupColumnName) -ne $null)
            {
			    $listField=$web.Fields.GetFieldByInternalName($ChildLookupColumnName)
			    $myList.Fields.Add($listField)
			    $myList.Update()
            }
            else
            {
                Write-Host "Site Column: $ChildLookupColumnName  Does not exist" 
            }

			}
		}
		      
	}
	else
	{
	    write-host "Field Exists already!" -f red
	} 
	
	
}

function CreateApprovedCalculatedField ($web) {

	#Variables
	$ListName="ApplicationFacilityLookup"
	$CalculatedColumnName="ApprovedApplications"
	
	#Get the List
	$list = $web.Lists.TryGetList($ListName)
	  
	
	if ($list -ne $null) {
		if (!$list.Fields.ContainsField($CalculatedColumnName)) {
			#Add new calculated column
			$list.Fields.Add($CalculatedColumnName, "Calculated", $false)
			 
			#Get the column
			$CalculatedCol = $List.Fields.GetField($CalculatedColumnName)
			#Set Formula for calculated column 
			  		
	  		$CalculatedCol.Formula="=IF(AND(OR([Application Status]=""Approved"",[Application Status]=""Approved with Major Modifications"",[Application Status]=""Approved with Minor Modifications""), ISBLANK(MovedToFacility)),[Study Title],"""")"   		
			$CalculatedCol.OutputType="Text"
			$CalculatedCol.Title="Approved Applications"
			$CalculatedCol.Update()
		}
	}
}
 
 function CreateApprovedSiteColumn($web) {
    #CREATE SITE COLUMNS
    echo "CREATING SITE COLUMNS"
    
	# GET THE LISTS
	$myList = $web.Lists["ApplicationFacilityLookup"];

	#Where the Source List for Lookup Exists
	
	$ParentWebURL=$web.Url
	$ParentListName="ApplicationFacilityLookup"
	$ParentLookupColumnName="Approved Applications"
	
	#Where the Lookup Site column Going to get created
	$ChildWebURL=$web.Url
	$ChildLookupColumnName="ApprovedApplicationsLookup"
	
	#Get the Parent and Child Webs and List
	
	$ParentWeb = Get-SPWeb $ParentWebURL
	$ParentList = $ParentWeb.Lists[$ParentListName]
	$ChildWeb = Get-SPWeb $ChildWebURL
	$ChildLookupColumnName="ApprovedApplicationsLookup"
	if(!$ChildWeb.Fields.ContainsFieldWithStaticName($ChildLookupColumnName))
	{
	    #Add Lookup Field
	
	    $ChildLookupColumn = $ChildWeb.Fields.AddLookup($ChildLookupColumnName,$ParentList.id,$False)
	    $ChildWeb.Update()

	    $ChildLookupColumn = $ChildWeb.Fields[$ChildLookupColumnName]
	
	    #Setup lookup Field property
	
	    $ChildLookupColumn.LookupWebId = $ParentWeb.ID
	
	    $ChildLookupColumn.LookupField = $ParentList.Fields[$ParentLookupColumnName].InternalName
	
	    $ChildLookupColumn.AllowMultipleValues=$true
	
	   	$ChildLookupColumn.Group="RAMS IRB" 
        $ChildLookupColumn.Title="Approved Applications Lookup"

	    $ChildLookupColumn.update()
        write-host "Lookup field added successfully to the $childWeb !" -f green
		  
	}
	else
	{
	    write-host "Field Exists already on the $childWeb !" -f red
	} 
    
	#CREATE LIST COLUMNS FROM SITE COLUMNS
	echo "CREATING LIST COLUMNS"
		
	$calendarName="RDC Calendar"
		
	# GET THE LISTS	    
	$myList = $web.Lists[$calendarName];
	if ($myList -ne $null) {
	    if (!$myList.Fields.ContainsFieldWithStaticName($ChildLookupColumnName)) {
            if($web.Fields.TryGetFieldByStaticName($ChildLookupColumnName) -ne $null)
            {
			    $listField=$web.Fields.TryGetFieldByStaticName($ChildLookupColumnName)
			    $myList.Fields.Add($listField)
			    $myList.Update()
                write-host "Lookup field added successfully to the $myList " -f green
            }
            else
            {
                Write-Host "Site Column: $ChildLookupColumnName  Does not exist" 
            }				

		} 
	} 

}

#This is to test the driver contains a $siteUrl
#$siteUrl="https://vaww.idev.ram.msp.va.gov/sites/IRBApplications/";
$w = Get-SPWeb $siteUrl;
GetAllWebs($siteUrl)
   