Add-PSSnapin Microsoft.SharePoint.Powershell

function GetAllWebs($url)
{
    try
    {
        Write-Host ([String]::Format("Procesing web {0}",$w.Url)) -foregroundcolor Blue
        if($w.Webs.Count -gt 0)
        {
            foreach($web in $w.Webs)
            {
			 	CreateMeetingMinuteLookup $web "RDC";
                CreateMeetingMinuteLookup $web "IACUC";
		        CreateMeetingMinuteLookup $web "SRS";
                CreateMeetingMinuteLookup $web "Committee"; #IRB
             }
        }
    }
    catch
    {
        Write-Host ([String]::Format("Error processing web at $url, with Exception: {0}", $_.Exception.Message)) -foregroundcolor Red
    }   
}


function CreateMeetingMinuteLookup ($web, $committee) {
    # GET THE SITE
    #$web = Get-SPWeb $siteURL
    
    #CREATE SITE COLUMNS
    echo "CREATING SITE COLUMNS"
    
    $calendarName=$committee + " Calendar"
	# GET THE LISTS
	$myList = $web.Lists[$calendarName];

	#Where the Source List for Lookup Exists
	
	$ParentWebURL=$web.Url
	
    $ParentListName=$committee + " Calendar"
	$ParentLookupColumnName="Title"
	
	#Where the Lookup Site column Going to get created
	$ChildWebURL=$web.Url
	
    $ChildLookupColumnName= $committee + "CalendarMeetingMinuteLookup"

	#Get the Parent and Child Webs and ListQ
	
	$ParentWeb = Get-SPWeb $ParentWebURL
	$ParentList = $ParentWeb.Lists[$ParentListName]
	$ChildWeb = Get-SPWeb $ChildWebURL
     
    #delete the site column if it already exist w/ same name
	if($ChildWeb.Fields.ContainsField($ChildLookupColumnName))	
	{
        $ChildWeb.Fields.Delete($ChildLookupColumnName)
        $ChildWeb.Update()
	}
    #add the column
	if(!$ChildWeb.Fields.ContainsField($ChildLookupColumnName))	
	{
	    #Add Lookup Field
	
	    $ChildLookupColumn = $ChildWeb.Fields.AddLookup($ChildLookupColumnName,$ParentList.id,$False)
	
	    $ChildLookupColumn = $ChildWeb.Fields[$ChildLookupColumnName]
	
	    #Setup lookup Field property
	
	    $ChildLookupColumn.LookupWebId = $ParentWeb.ID
	
	    $ChildLookupColumn.LookupField = $ParentList.Fields[$ParentLookupColumnName].InternalName
	
	    $ChildLookupColumn.AllowMultipleValues=$true
	
	   	$ChildLookupColumn.Group="RAMS IRB" 
        $ChildLookupColumn.Title=$committee + " Meeting Minute Lookup"

	    $ChildLookupColumn.update()	

        write-host "Lookup field added successfully to the site!" -f green
	}
    $ChildLookupColumn = $ChildWeb.Fields.TryGetFieldByStaticName($ChildLookupColumnName)
    #Add column to the Calendar List, if missing
    if($myList.Fields.ContainsFieldWithStaticName($ChildLookupColumnName) -eq $True)
    {    
        $myList.Fields.Delete($ChildLookupColumnName)
        $myList.Update()
    }	
   	$myList.Fields.Add($ChildLookupColumn)
	$myList.Update()
 	write-host "Lookup field added successfully to the Calendar List!" -f green

}

#This is to test the driver contains a $siteUrl
#$siteUrl="http://vaww.idev.ram.msp.va.gov/sites/IRBApplications";
$w = Get-SPWeb $siteUrl;
GetAllWebs($siteUrl)