<#
The following script Deploys the following Site Features for the given sprint.
1)CommitteeBroker workflow from the template CommitteeBroker.wsp provided.

* For each Feature, DeployFeature function is called with following parameters.
Parameters:
 $SiteCollection: the url of the Site Collection where Solution needs to be added
 $site: the url of the site where the Feature needs to be enabled
 $FeatureName: The name of the template/Feature/Solution
 $FeatureId: Feature Id from the template
 $file: source file of the feature

 The Feature Id is required which you may need to extract from the template provided.
To extract the feature id:

1) Make a copy of the .wsp file and change the file name extension on the copied file to .cab.
2) In Windows Explorer, right-click the .cab file, and then click Open.
3) Select feature.xml. The feature id is given in the Feature tag 
< Feature  id = {Feature id here} >
.......
</Feature>

The function performs following tasks.
1) It adds the workflow to the Solutions in the '$SiteCollection'
2) Activates the solution
3) Enable the feature for the given '$site'
#>
Function DeployFeature {

Param(          [Parameter(Mandatory=$True)]
                [string]$SiteCollection,

                [Parameter(Mandatory=$True)]
                [string]$site,

                [Parameter(Mandatory=$True)]
                [string]$FeatureName,

                [Parameter(Mandatory=$True)]
                [string]$OldFeatureId,

                [Parameter(Mandatory=$True)]
                [string]$FeatureId,

                [Parameter(Mandatory=$True)]
                [string]$file,

                [Parameter(Mandatory=$True)]
                [bool] $bolUninstall,

                [Parameter(Mandatory=$False)]
                [bool] $bolEnableFeatureOnly   
                )
    

        Add-PSSnapin Microsoft.SharePoint.PowerShell

    # GET THE SITE COLLECTION
    $SiteCollectionweb = Get-SPWeb $SiteCollection

    # GET THE SITE
    $web = Get-SPWeb $site

    # CLEAN and old one first
    if($bolEnableFeatureOnly -eq $False) {
        if($bolUninstall)
        {
            Write-Host "  Uninstall old ones"
            
            Write-Host "    Disabling feature Identity $OldFeatureId URL $web.Url"
            Disable-SPFeature -Identity $OldFeatureId -Url $SiteCollectionweb.Url -Force   
            
            Write-Host "    Uninstalling feature Identity $FeatureName Site $SiteCollectionweb.Url"
            Uninstall-SPUserSolution -Identity $FeatureName -Site $SiteCollectionweb.Site 
            
            Write-Host "    Removing feature Identity $FeatureName Site $SiteCollectionweb.Url"
            Remove-SPUserSolution -Identity $FeatureName -Site $SiteCollectionweb.Site 
            $web.Update()      
        }
        # ADD/UPLOAD TO THE SOLUTIONS
        Write-Host "  Adding new ones"
        Write-Host "    Adding feature file $file Site $SiteCollectionweb.Url"
        Add-SPUSerSolution -LiteralPath $file -Site $SiteCollectionweb.Url -Verbose 
        $web.Update()
        # ACTIVATE THE SOLUTION
        Write-Host "  Activating new ones"
        Write-Host "    Install feature Identity $FeatureName Site $SiteCollectionweb.Url"
        Install-SPUserSolution -Identity $FeatureName -Site $SiteCollectionweb.Url 
        $web.Update()
    }
    # ENABLE THE FEATURE FOR THE GIVEN SITE
    # feature id goes into -Identity
    Write-Host "  Enabling new ones"
    Write-Host "    Enabling feature Identity $FeatureName Url $web.Url"
    Enable-SPFeature -Identity $FeatureId -Url $web.Url -Verbose -Force
    $web.Update()
}


# ENTER YOUR FEATURE DEPLOYMENT CALLS HERE

# DEPLOYING COMMITTEEBROKER WORKFLOW, for explaination read instructions at the TOP
#DeployFeature -SiteCollection "http://vaww.itst.ram.msp.va.gov/sites/IRBApplications" -site "http://DNS.URL/sites/IRBApplications" -FeatureName "CommitteeBroker.wsp" -FeatureId "e760f313-7180-49f8-8a69-ff2b41396320" -file C:\Users\DNS   DNS\Desktop\CommitteeBroker.wsp 

#DeployFeature -SiteCollection $siteUrl -site $web.Url -FeatureName "Add To SRS Agenda.wsp" -FeatureId "965cc6af-32ab-4c56-a261-cca6a291ce59" -file $script -bolUninstall $True	 
<#
$w = Get-SPWeb $siteURL
if($w.Webs.Count -gt 0)
{
    foreach($web in $w.Webs)
    {
        DeployFeature -SiteCollection $siteUrl -site $web -FeatureName "Add To RDC Agenda.wsp" -OldFeatureId "3ed1c459-0e4b-4a9e-a2bd-6bf4562f7a8f" -FeatureId "17c810d2-237e-4c89-bbda-d88d34f2bdb7" -file $script -bolUninstall $True	 
    }
}

#>
#echo "ALL DONE!!"
#DeployFeature -SiteCollection $siteUrl -site $w.Url -FeatureName "Notification Workflow Configuration Workflow.wsp" -OldFeatureId $tempFeatureId -FeatureId "6c1a9661-5e24-44be-8b0b-52b19bcd765da" -file $script -bolUninstall $True	 

$web.update()