<#

RAMS Release: 2.2
Last updated: November 11th 2017
Author: By-Light

Assumptions :
- The user executing the script must be part of the Site Collection Administration group.

#>

#SPSite
Param( [Parameter(Mandatory=$True)]
	[string]$siteUrl,
	
	[Parameter(Mandatory=$True)]
	[string]$fileLocationPS,
	
	[Parameter(Mandatory=$True)]
	[string]$fileLocationTemplate,
	
	[Parameter(Mandatory=$True)]
	[string]$fileLocationSiteAsset,
	
	[Parameter(Mandatory=$True)]
	[string]$reportTargetServerName,
	
	[Parameter(Mandatory=$True)]
	[string]$reportSourceDirectory,
	
	[Parameter(Mandatory=$True)]
	[string]$wfTempFileLocation,
	
	# DataSources Connection string Table
	[Parameter(Mandatory=$True)]
	[hashtable]$rdsConnStringTable,
	
	# DataSource Credentials: Username and Password if needed
	[Parameter(Mandatory=$True)]
	[hashtable]$rdsCredentialsTable

)

Add-PSSnapin Microsoft.SharePoint.PowerShell

$perComplete = 0 
$count = 3
$ConfirmPreference = "None"

Write-Progress -Activity "RAMS 2.2 Deployment - Step: 1.1 [UpdateDataSharingRepositoryAgreements]" -PercentComplete $perComplete
#Step 2 create UpdateDataSharingRepositoryAgreements
# include the UpdateDataSharingRepositoryAgreements.
$scriptInc = Join-Path $fileLocationPS UpdateDataSharingRepositoryAgreements.ps1
echo $scriptInc
. $scriptInc

Write-Progress -Activity "RAMS 2.2 Deployment - Step: 1.2 [CreateSRSDocumentLibrary]" -PercentComplete $perComplete
#Step 2 create CreateSRSDocumentLibrary
# include the CreateSRSDocumentLibrary.
$scriptInc = Join-Path $fileLocationPS CreateSRSDocumentLibrary.ps1
echo $scriptInc
. $scriptInc

$perComplete = $perComplete + $count
Write-Progress -Activity "RAMS 2.2 Deployment - Step: 2 [CreateApplicationFacilityLookup]" -PercentComplete $perComplete
#Step 1 Include CreateApplicationFacilityLookup
# include the CreateApplicationFacilityLookup.
$scriptInc = Join-Path $fileLocationPS CreateApplicationFacilityLookup.ps1 
echo $scriptInc
. $scriptInc

$perComplete = $perComplete + $count
Write-Progress -Activity "RAMS 2.2 Deployment - Step: 3 [CreateCalculatedFieldsAndLookups.ps1]" -PercentComplete $perComplete
#Step 3 create CreateCalculatedFieldsAndLookups
# include the CreateCalculatedFieldsAndLookups.
$scriptInc = Join-Path $fileLocationPS CreateCalculatedFieldsAndLookups.ps1
echo $scriptInc
. $scriptInc

$perComplete = $perComplete + $count
Write-Progress -Activity "RAMS 2.2 Deployment - Step: 4 [CreateSRSCalendar.ps1]" -PercentComplete $perComplete
#Step 4 CreateSRSCalendar
# include the CreateSRSCalendar
$scriptInc = Join-Path $fileLocationPS CreateSRSCalendar.ps1
echo $scriptInc
. $scriptInc

$perComplete = $perComplete + $count
Write-Progress -Activity "RAMS 2.2 Deployment - Step: 5 [MigrateFacilityData]" -PercentComplete $perComplete
#Step 6 create MigrateFacilityData
# include the MigrateFacilityData.
$scriptInc = Join-Path $fileLocationPS MigrateFacilityData.ps1
echo $scriptInc
. $scriptInc

$perComplete = $perComplete + $count
Write-Progress -Activity "RAMS 2.2 Deployment - Step: 6 [MigrateLookupData]" -PercentComplete $perComplete
#Step 7 create MigrateLookupData
# include the MigrateLookupData.
$scriptInc = Join-Path $fileLocationPS MigrateLookupData.ps1
echo $scriptInc
. $scriptInc -siteUrl $siteUrl

$perComplete = $perComplete + $count
Write-Progress -Activity "RAMS 2.2 Deployment - Step: 7 [RemoveOldFieldsAfterMigration]" -PercentComplete $perComplete
#Step 8 create RemoveOldFieldsAfterMigration
# include the RemoveOldFieldsAfterMigration.
$scriptInc = Join-Path $fileLocationPS RemoveOldFieldsAfterMigration.ps1
echo $scriptInc
. $scriptInc

$perComplete = $perComplete + $count
Write-Progress -Activity "RAMS 2.2 Deployment - Step: 8 [CreateMinuteLookups]" -PercentComplete $perComplete
#Step 5 create CreateMinuteLookups
# include the CreateMinuteLookups.
$scriptInc = Join-Path $fileLocationPS CreateMinuteLookups.ps1
echo $scriptInc
. $scriptInc

$perComplete = $perComplete + $count
Write-Progress -Activity "RAMS 2.2 Deployment - Step: 9 [CreateApprovedColumnToRDC]" -PercentComplete $perComplete
#Step 9 create CreateApprovedColumnToRDC
# include the CreateApprovedColumnToRDC.
$scriptInc = Join-Path $fileLocationPS CreateApprovedColumnToRDC.ps1
echo $scriptInc
. $scriptInc

$perComplete = $perComplete + $count
Write-Progress -Activity "RAMS 2.2 Deployment - Step: 10 [RegenerateCalendarForms]" -PercentComplete $perComplete
#Step 9 create RegenerateCalendarForms
# include the RegenerateCalendarForms.
$scriptInc = Join-Path $fileLocationPS RegenerateCalendarForms.ps1
echo $scriptInc
. $scriptInc

$perComplete = $perComplete + $count
Write-Progress -Activity "RAMS 2.2 Deployment - Step: 11 [FixCalendarOrder.ps1]" -PercentComplete $perComplete
#Step 10 create FixCalendarOrder.ps1
# include the FixCalendarOrder.ps1.
$scriptInc = Join-Path $fileLocationPS FixCalendarOrder.ps1
echo $scriptInc
. $scriptInc

$perComplete = $perComplete + $count
Write-Progress -Activity "RAMS 2.2 Deployment - Step: 12 [CreateRCOGroup.ps1]" -PercentComplete $perComplete
# include the CreateRCOGroup.ps1.
$scriptInc = Join-Path $fileLocationPS CreateRCOGroup.ps1
echo $scriptInc
. $scriptInc

$perComplete = $perComplete + $count
Write-Progress -Activity "RAMS 2.2 Deployment - Step: 13 [DeploySiteFeatures]" -PercentComplete $perComplete
# include the DeploySiteFeatures.
$scriptInc = Join-Path $fileLocationPS DeploySiteFeatures.ps1 
echo $scriptInc
. $scriptInc


#region AddFacilityWorkflow
function AddFacilityWorkflow ($oldFeatureName, $featureTemplateName, $newFeatureId, $searchDisplay, $listName)
{
 #try
 #   {
      Write-Host ([String]::Format("Procesing web {0}",$w.Url)) -foregroundcolor Cyan            
      $bolEnableFeatureOnly = $False #initialize
   	  # GET THE SITE
      $w = Get-SPWeb $siteURL
        if($w.Webs.Count -gt 0)
        {
            foreach($web in $w.Webs)
            {   
                #Enable old workflows from 2.1 or before
                if($oldFeatureName -contains "*IACUC*" -or $oldFeatureName -contains "*RDC*") {            
                    Enable-SPFeature -Identity $oldFeatureName -Url $web.Url -Verbose -Force
                    Enable-SPFeature -Identity $oldFeatureName -Url $siteUrl -Verbose -Force
                }
                $web.Update()
                #get above old workflows
                #$Oldfeature = Get-SPFeature -Limit ALL  -Web $web.Url  | Where-Object {$_.DisplayName -like $searchDisplay}
                $Oldfeature = $null #initialize

                if($bolEnableFeatureOnly -eq $False) {
                   try {
                    $Oldfeature = Get-SPFeature -Identity $oldFeatureName -Web $siteUrl 
                    }
                    catch {
                      Write-Host "Feature: $oldFeatureName does not exist for Site: $web.Url"
                    }
                }
                $tempFeatureId = $Oldfeature.Id             
                if ($tempFeatureId -eq $null)
                {
                    $tempFeatureId = $newFeatureId
                }
            	Write-Host "Calling DeployFeature on $web with $featureTemplateName OldFeatureId $tempFeatureId FeatureId $newFeatureId "
                if($bolEnableFeatureOnly -eq $False) {
            	    DeployFeature -SiteCollection $siteUrl -site $web.Url -FeatureName $featureTemplateName -OldFeatureId $tempFeatureId -FeatureId $newFeatureId -file $script -bolUninstall $True	 -bolEnableFeatureOnly $bolEnableFeatureOnly
                    $bolEnableFeatureOnly = $True
                }
                else {
                    DeployFeature -SiteCollection $siteUrl -site $web.Url -FeatureName $featureTemplateName -OldFeatureId $tempFeatureId -FeatureId $newFeatureId -file $script -bolUninstall $True	 -bolEnableFeatureOnly $bolEnableFeatureOnly
                }
                #add workflow to the list (association)
                #Write-Host "Associating $featureTemplateName to the list $listName"
                #$CalendarList  =$web.Lists[$listName]             
            }
        }
 #   }
 #   catch
 #   {
 #       Write-Host ([String]::Format("Error processing web at $url, with Exception: {0}", $_.Exception.Message)) -foregroundcolor Red
 #   }   
}
#endregion 


$perComplete = $perComplete + $count
Write-Progress -Activity "RAMS 2.2 Deployment - Step: 14.0 [CleanOldWorkFlows]" -PercentComplete $perComplete
$scriptInc = Join-Path $fileLocationPS CleanOldWorkFlows.ps1 
echo $scriptInc
. $scriptInc

$perComplete = $perComplete + $count
Write-Progress -Activity "RAMS 2.2 Deployment - Step: 14.1 Workflow - Add To SRS Agenda" -PercentComplete $perComplete
$script = Join-Path $fileLocationTemplate "Add To SRS Agenda.wsp"
echo $script
AddFacilityWorkflow -oldFeatureName "Add To SRS AgendaListInstances" -featureTemplateName "Add To SRS Agenda.wsp" -newFeatureId "4976cc13-e189-4467-9e08-102b8dcdc673" -searchDisplay "*SRS Agenda*"
 
Write-Progress -Activity "RAMS 2.2 Deployment - Step: 14.2 Workflow - Add To IACUC Agenda" -PercentComplete $perComplete
$script = Join-Path $fileLocationTemplate "Add To IACUC Agenda.wsp"
echo $script
AddFacilityWorkflow -oldFeatureName "Add To IACUC AgendaListInstances" -featureTemplateName "Add To IACUC Agenda.wsp" -newFeatureId "77e53849-9785-4e0b-9999-20b2e0a37ae7" -searchDisplay "*IACUC Agenda*"

Write-Progress -Activity "RAMS 2.2 Deployment - Step: 14.3 Workflow - Add To RDC Agenda" -PercentComplete $perComplete
$script = Join-Path $fileLocationTemplate "Add To RDC Agenda.wsp"
echo $script
AddFacilityWorkflow -oldFeatureName "Add To RDC AgendaListInstances" -featureTemplateName "Add To RDC Agenda.wsp" -newFeatureId "73b4bf88-4552-40f2-824d-b1f11accb96a" -searchDisplay "*RDC Agenda*"

#region Add Site Collection level workflow
function AddSiteCollectionWorkFlow ($featureTemplateName, $newFeatureId, $oldFeatureId, $searchDisplay) {
 try
    {
        Write-Host ([String]::Format("Procesing web {0}",$w.Url)) -foregroundcolor Cyan            
    
   	    # GET THE SITE
        $w = Get-SPWeb $siteURL        
        #$featureTemplateName="Notification Workflow Configuration Workflow.wsp"
        #$newFeatureId="df439192-e32f-4760-9bef-d239d8519593"
        
        $Oldfeature = Get-SPFeature -Limit ALL  -Web $w.Url | Where-Object {$_.DisplayName -like $searchDisplay}   
        $tempFeatureId = $Oldfeature.Id             
        if ($tempFeatureId -eq $null)
        {
            $tempFeatureId = $oldFeatureId
        }
      	Write-Host "Calling DeployFeature on $w with $featureTemplateName OldFeatureId $tempFeatureId FeatureId $newFeatureId "
        DeployFeature -SiteCollection $siteUrl -site $w.Url -FeatureName $featureTemplateName -OldFeatureId $tempFeatureId -FeatureId $newFeatureId -file $script -bolUninstall $True -bolEnableFeatureOnly $False	 

    }
    catch
    {
        Write-Host ([String]::Format("Error processing web at $url, with Exception: {0}", $_.Exception.Message)) -foregroundcolor Red
    }  
}
#endregion
 
Write-Progress -Activity "RAMS 2.2 Deployment - Step: 14.5.1 Workflow - Notification Worflow Configuration" -PercentComplete $perComplete
$script = Join-Path $fileLocationTemplate "Notification Workflow Configuration Workflow.wsp"
echo $script
AddSiteCollectionWorkFlow -featureTemplateName "Notification Workflow Configuration Workflow.wsp" -newFeatureId "df439192-e32f-4760-9bef-d239d8519593" -oldFeatureId "6c1a9661-5e24-44be-8b0b-52b19bcd765d" -searchDisplay "*Notification Workflow Config*"


Write-Progress -Activity "RAMS 2.2 Deployment - Step: 14.5.2 Workflow - CommitteeBroker" -PercentComplete $perComplete
$script = Join-Path $fileLocationTemplate "CommitteeBroker.wsp"
echo $script
AddSiteCollectionWorkFlow -featureTemplateName "CommitteeBroker.wsp" -newFeatureId "94976d9b-5736-48e6-9a36-f04888b10e97" -oldFeatureId "94976d9b-5736-48e6-9a36-f04888b10e97" -searchDisplay "*Broker*"


Write-Progress -Activity "RAMS 2.2 Deployment - Step: 14.6 Workflow - Add To Committee Calendar" -PercentComplete $perComplete
$script = Join-Path $fileLocationTemplate "Add To Committee Calendar.wsp"
echo $script
AddFacilityWorkflow -oldFeatureName "New Agenda Notification WF" -featureTemplateName "Add To Committee Calendar.wsp" -newFeatureId "984e3619-26cb-4d04-928a-a4dc29450715" -searchDisplay "*Committee Calendar*"

$perComplete = $perComplete + $count
Write-Progress -Activity "RAMS 2.2 Deployment - Step: 15 [Deploy Files]" -PercentComplete $perComplete
#Step 11 DeployFiles
# include the DeployeFiles.
$scriptInc = Join-Path $fileLocationPS DeployFiles.ps1
echo $scriptInc
. $scriptInc

$perComplete = $perComplete + $count
Write-Progress -Activity "RAMS 2.2 Deployment - Step: 16" -PercentComplete $perComplete
echo "Run Reports deployment script"
$scriptInc = Join-Path $fileLocationPS Reports_Import.ps1
echo $scriptInc
. $scriptInc -webServiceUrl $reportTargetServerName -reportFolder "RAMS Reports" -DataSourcesFolder "Data Sources" -SourceDirectory $reportSourceDirectory -overwrite $True -rdsConnStringTable $rdsConnStringTable -rdsCredentialsTable $rdsCredentialsTable

$perComplete = $perComplete + $count
Write-Progress -Activity "RAMS 2.2 Deployment - Step: 17" -PercentComplete $perComplete
echo "Apply Master Page"
$scriptInc = Join-Path $fileLocationPS MasterPageSetter.ps1
echo $scriptInc
. $scriptInc

$perComplete = $perComplete + $count
Write-Progress -Activity "RAMS 2.2 Deployment - Step: 18" -PercentComplete $perComplete
echo "UpdateMaxQueryLookupFields"
$scriptInc = Join-Path $fileLocationPS UpdateMaxQueryLookupFields.ps1
echo $scriptInc
. $scriptInc

$perComplete = $perComplete + $count
Write-Progress -Activity "RAMS 2.2 Deployment - Step: 19 " -PercentComplete $perComplete
echo "ScheduleTask"
$scriptInc = Join-Path $fileLocationPS ScheduleTask.ps1
echo $scriptInc
. $scriptInc

$perComplete = $perComplete + $count
Write-Progress -Activity "RAMS 2.2 Deployment - Step: 20" -PercentComplete $perComplete 
echo "UpdateCommitteeFacilityList"
$scriptInc = Join-Path $fileLocationPS UpdateCommitteeFacilityList.ps1
echo $scriptInc
. $scriptInc

Write-Host "Starting Security Patch" -ForegroundColor Cyan
$perComplete = $perComplete + $count
Write-Progress -Activity "RAMS 2.2 Deployment - Step: 21.1: Security Patch=SG_AddUsersToSiteAssets" -PercentComplete $perComplete 
echo "SG_AddUsersToSiteAssets"
$scriptInc = Join-Path $fileLocationPS SG_AddUsersToSiteAssets.ps1
echo $scriptInc
. $scriptInc

Write-Progress -Activity "RAMS 2.2 Deployment - Step: 21.2: Security Patch=SGRemoveIRBApplicationsPermissions" -PercentComplete $perComplete 
echo "SGRemoveIRBApplicationsPermissions"
$scriptInc = Join-Path $fileLocationPS SGRemoveIRBApplicationsPermissions.ps1
echo $scriptInc
. $scriptInc

$perComplete = $perComplete + $count
Write-Progress -Activity "RAMS 2.2 Deployment - Step: 21.3: Security Patch=SG_RemoveIrbApplicationGeneralHtmlPermissions" -PercentComplete $perComplete 
echo "SG_RemoveIrbApplicationGeneralHtmlPermissions"
$scriptInc = Join-Path $fileLocationPS SG_RemoveIrbApplicationGeneralHtmlPermissions.ps1
echo $scriptInc
. $scriptInc

Write-Progress -Activity "RAMS 2.2 Deployment - Step: 21.4: Security Patch=SG_RemoveUniquePermissions" -PercentComplete $perComplete 
echo "SG_RemoveUniquePermissions"
$scriptInc = Join-Path $fileLocationPS SG_RemoveUniquePermissions.ps1
echo $scriptInc
. $scriptInc

Write-Progress -Activity "RAMS 2.2 Deployment - Step: 21.5: Security Patch=SGAgendaReport" -PercentComplete $perComplete 
echo "SGAgendaReport"
$scriptInc = Join-Path $fileLocationPS SGAgendaReport.ps1
echo $scriptInc
. $scriptInc

Write-Progress -Activity "RAMS 2.2 Deployment - Step: 21.6: Security Patch=SG_RenameGroupNames" -PercentComplete $perComplete 
echo "SG_RenameGroupNames"
$scriptInc = Join-Path $fileLocationPS SG_RenameGroupNames.ps1
echo $scriptInc
. $scriptInc

Write-Progress -Activity "RAMS 2.2 Deployment - Step: 21.7: Security Patch=SG_UpdateGroupOwners" -PercentComplete $perComplete 
echo "SG_UpdateGroupOwners"
$scriptInc = Join-Path $fileLocationPS SG_UpdateGroupOwners.ps1
echo $scriptInc
. $scriptInc

Write-Progress -Activity "RAMS 2.2 Deployment - Step: 21.8: Security Patch=SG_SyncFacilityList" -PercentComplete $perComplete 
echo "SG_SyncFacilityList"
$scriptInc = Join-Path $fileLocationPS SG_SyncFacilityList.ps1
echo $scriptInc
. $scriptInc

Write-Progress -Activity "RAMS 2.2 Deployment - Step: 21.9: Security Patch=SG_SyncCommitteeList" -PercentComplete $perComplete 
echo "SG_SyncCommitteeList"
$scriptInc = Join-Path $fileLocationPS SG_SyncCommitteeList.ps1
echo $scriptInc
. $scriptInc

Write-Progress -Activity "RAMS 2.2 Deployment - Step: 21.10: Security Patch=SG_SyncSiteConfigList" -PercentComplete $perComplete 
echo "SG_SyncSiteConfigList"
$scriptInc = Join-Path $fileLocationPS SG_SyncSiteConfigList.ps1
echo $scriptInc
. $scriptInc

$perComplete = $perComplete + $count
Write-Progress -Activity "RAMS 2.2 Deployment - Step: 22" -PercentComplete $perComplete 
echo "UpdateEnvironmentList"
$scriptInc = Join-Path $fileLocationPS UpdateEnvironmentList.ps1
echo $scriptInc
. $scriptInc

Write-Progress -Activity "RAMS 2.2 Deployment completed" -PercentComplete $perComplete -Completed 
