﻿Add-PSSnapin Microsoft.SharePoint.Powershell



function formatOutput($listTable) {
  $listTable | Format-List
}

function getInternalName ($staticName, $list) {
    $list.Fields.TryGetFieldByStaticName($staticName).InternalName
    return;
}

function GetdataFrom3List ($days)
{
    #filter by days
    $count = $collListItems.Count;
    $date = get-date;
    $filterDays = $date.AddDays($days);

    #get site collection
    $site = Get-SPSite | Select-String IRBApplications
    $x = $site.ToString();
    $url = $x.Substring($x.IndexOf("=")+1)
    $w = Get-SPWeb $url

    #get application list
    $list = $w.Lists.TryGetList("Application")
    $committeeList = $w.Lists.TryGetList("Committee List")
    $facilityList = $w.Lists.TryGetList("Facility")
    if($list -ne $null)
    {
        #Get all items in this list and save them to a variable
        $items = $list.items
        $itemCount = 1
        #Go through all items
        foreach($item in $items)
        {
           if($item["Created"] -gt $filterDays)
            { 
                #print set of columns  
                Write-Host Application List Data for Study#: $item["Study_ID"] -ForegroundColor Cyan 
                Write-Host "*************************************************" -ForegroundColor DarkCyan
                #$fldName = getInternalName -columnName "StudyId"-listUrl "Lists/Application/AllItems.aspx" 
                $appListTable = @{
                    $list.Fields.TryGetFieldByStaticName("Created_x0020_Date").InternalName = $item["Created_x0020_Date"];                    
                    $list.Fields.TryGetFieldByStaticName("Study_ID").InternalName = $item["Study_ID"];
                    $list.Fields.TryGetFieldByStaticName("StudyTitle").InternalName = $item["StudyTitle"];
                    $list.Fields.TryGetFieldByStaticName("AssignedIRBAdministrator").InternalName = $item["AssignedIRBAdministrator"];
                    $list.Fields.TryGetFieldByStaticName("Reviewers").InternalName = $item["Reviewers"];
                    $list.Fields.TryGetFieldByStaticName("PrimaryReviewers").InternalName = $item["PrimaryReviewers"];
                    $list.Fields.TryGetFieldByStaticName("FacilityLookup").InternalName = $item["FacilityLookup"];
                };               
                formatOutput -listTable $appListTable 
                #Format-Table  $item["Created_x0020_Date"], $item["StudyId"], $item["StudyTitle"], $item["AssignedIRBAdministrator"], $item["Reviewers"], $item["PrimaryReviewers"], $item["FacilityLookup"] 
                #Get set of fields from Facility List for the above facility
                $pos = $item["FacilityLookup"].IndexOf("#")                
                $facilityName = $item["FacilityLookup"].Substring($pos+1)
                $facilityItems = $facilityList.items
                foreach($facilityItem in $facilityItems)
                {
                    if($facilityItem["Facility Name"] -eq $facilityName) {
                        Write-Host "Facility List Data for $facilityName :" -ForegroundColor Green
                        #Format-Table $facilityItem["Facility Name"], $facilityItem["Facility Liaison"], $facilityItem["Committee Lookup"]
                        $facilityListTable = @{
                            $facilityList.Fields.TryGetFieldByStaticName("FacilityName").InternalName = $facilityItem["Facility Name"];
                            $facilityList.Fields.TryGetFieldByStaticName("FacilityLiaison").InternalName = $facilityItem["Facility Liaison"];
                            $facilityList.Fields.TryGetFieldByStaticName("CommitteeLookup").InternalName = $facilityItem["Committee Lookup"];
                        };               
                        formatOutput -listTable $facilityListTable 
                    }
                }
                #Get set of fields from Committee list for the above facility
                $committeeItems = $committeeList.items
                foreach($committeeItem in $committeeItems)
                {
                    if($committeeItem["Title"] -eq $facilityName) {
                        Write-Host "Commitee List Data for $facilityName :" -ForegroundColor Magenta

                        $committeeListTable = @{
                            $committeeList.Fields.TryGetFieldByStaticName("Title").InternalName = $committeeItem["Title"];
                            $committeeList.Fields.TryGetFieldByStaticName("IRBAdministrators").InternalName = $committeeItem["IRBAdministrators"];
                            $committeeList.Fields.TryGetFieldByStaticName("IRBCommitteeAdministrators").InternalName = $committeeItem["IRBCommitteeAdministrators"];
                            $committeeList.Fields.TryGetFieldByStaticName("IRBCommitteeCoordinators").InternalName = $committeeItem["IRBCommitteeCoordinators"];
                            $committeeList.Fields.TryGetFieldByStaticName("IRBCommitteeMembers").InternalName = $committeeItem["IRBCommitteeMembers"];
                            $committeeList.Fields.TryGetFieldByStaticName("RDCCommitteeAdministrators").InternalName = $committeeItem["RDCCommitteeAdministrators"];
                            $committeeList.Fields.TryGetFieldByStaticName("RDCCommitteeCoordinators").InternalName = $committeeItem["RDCCommitteeCoordinators"];
                            $committeeList.Fields.TryGetFieldByStaticName("RDCCommitteeMembers").InternalName = $committeeItem["RDCCommitteeMembers"];
                            $committeeList.Fields.TryGetFieldByStaticName("CommitteeCoordinators").InternalName = $committeeItem["CommitteeCoordinators"];
                            $committeeList.Fields.TryGetFieldByStaticName("CommitteeMembers").InternalName = $committeeItem["CommitteeMembers"];
                            $committeeList.Fields.TryGetFieldByStaticName("LocalSiteAdministrators").InternalName = $committeeItem["LocalSiteAdministrators"];
                            $committeeList.Fields.TryGetFieldByStaticName("LocalSiteLiaisons").InternalName = $committeeItem["LocalSiteLiaisons"];
                        };               
                        formatOutput -listTable $committeeListTable
                        Write-Host "*************************************************" -ForegroundColor DarkCyan                       
                    }
                }                
            }
        }
    }
}

GetdataFrom3List -days -5;

