Param( [Parameter(Mandatory=$True)]
	[string]$localSiteUrl
)

Add-PSSnapin Microsoft.SharePoint.Powershell


$facilities = @{
}

$recordCounts = @{
}

$recordChangedCounts = @{
}

function GetAllWebs($url)
{
    #try
    #{
        Write-Host ([String]::Format("Procesing web {0}",$w.Url)) -foregroundcolor cyan
        $applicationlist =$w.Lists["Application"]
        $applicationitems = $applicationlist.items
        
        
        #Loop through List
        #Get Facility Lookup
        #Copy record to correct list
	  	foreach ($item in $applicationitems) {
			
			
			$applicationStatusField = $item["Application Status"] 
			$applicationStudyTitleField = $item["Study Title"] 
			$applicationStudyIDField = $item["Study_ID"] 
			$applicationTitleField = $item["Title"];
			$idField = $item["ID"] 
            $applicationFacilityLookup=$item["Facility Lookup"]
            if ($applicationFacilityLookup -ne $null) {
                $applicationFacilityLookup = $applicationFacilityLookup.Substring(3)    
            }
	        if($w.Webs.Count -gt 0 -and $applicationFacilityLookup)
	        {
	         
	            foreach($web in $w.Webs)	           {
                     
                     $facilityNameKey=$web.Url;
	   				 $facilityNameLookup=$facilities.Item($web.Url);
	   
                        if($facilityNameLookup -eq $applicationFacilityLookup -and $applicationStatusField -ne 'Draft') {  				 	
                            MigrateToNewList $web $applicationStatusField $applicationStudyTitleField $idField $applicationStudyIDField $applicationTitleField                            
	   				 	}	   				
	   				
	            }
	        }
        }
     		 	 
    #}
    #catch
    #{
    #    Write-Host ([String]::Format("Error processing web at $url, with Exception: {0}", $_.Exception.Message)) -foregroundcolor Red
    #}   
 } 
    
   function getAllFacilities ($rootSiteCollectionUrl)
   {
  
    #Get the target SP Web
    $scWeb = Get-SPWeb -identity $rootSiteCollectionUrl
    
    #Get the Source List
    $facilityList = $scWeb.Lists["Facility"]
    $facilityitems = $facilityList.items
    
    foreach($facilityItem in $facilityitems)
    {
        $facilityName=$facilityItem["Facility Name"]
        $fldurl=new-object Microsoft.SharePoint.SPFieldUrlValue($facilityItem["FacilitySubsite"])
        $facilitySubsite=$fldurl.URL
        $facilityId=$facilityItem["ID"]
        #Write-Host "Adding facilities Name=$facilityName ID=$facilityId URL=$facilitySubsite"
        $facilities.add($facilitySubsite, $facilityName)
    }
}


   function getRecordCounts ($rootSiteCollectionUrl)
   {

        $applicationlist =$w.Lists["Application"]
        $applicationitems = $applicationlist.items
        $count = 0
        
        #Loop through List
        #Get Facility Lookup
        #Copy record to correct list
	  	foreach ($item in $applicationitems) {
            $count++
            $applicationFacilityLookup=$item["Facility Lookup"]
            
            if ($applicationFacilityLookup -ne $null -and $applicationFacilityLookup -ne "") {
                $applicationFacilityLookup = $applicationFacilityLookup.Substring(3)
                $currentFacilityCount = $recordCounts.Item($applicationFacilityLookup)
                
                if ($currentFacilityCount -ne $null) {
                    $currentFacilityCount++
                    $recordCounts.Remove($applicationFacilityLookup)
                    $recordCounts.add($applicationFacilityLookup, $currentFacilityCount)
                }
                else {
                    $currentFacilityCount=1
                    $recordCounts.add($applicationFacilityLookup, $currentFacilityCount)
                }
            }

          
        }     

       $recordCounts.add("ApplicationTotalCount", $count)
    }
    
    function MigrateToNewList($subsite, $applicationStatusField, $applicationStudyTitleField, $idField, $studyIDField, $applicationTitleField) 
	{
		
    
    #Get the target SP Web
    $scWeb = Get-SPWeb -identity $subsite.URL
    
    #Get the Source List
    $applicationFacilityLookupList = $scWeb.Lists["ApplicationFacilityLookup"]
    $lookupRecorditems = $applicationFacilityLookupList.items
 
    $applicationRecordIDField="ApplicationRecordID"
    $facilityLookupItems = $applicationFacilityLookupList.Items | where {$_[$applicationRecordIDField] -eq $idField}
   
    $updatedKey = $subsite.Title + "-Updated"
    $updatedCounts = $recordChangedCounts.Item($updatedKey)

    $newKey = $subsite.Title + "-New"
    $newCounts = $recordChangedCounts.Item($newKey)
    

    $listName = "ApplicationFacilityLookup"
    if ($facilityLookupItems -eq $null) {
        $list = $web.Lists[$listname]
        if ($list -ne $null) {
	        Write-Host "Migrate To New List" $subsite.Title
	        $newItem = $list.AddItem()
	        $newItem["Application Status"] = $applicationStatusField
	        $newItem["Study Title"] = $applicationStudyTitleField
	        $newItem["ApplicationRecordID"] = $idField
	        $newItem["Study_ID"] = $studyIDField
	        $newItem["Title"] = $applicationTitleField
            $newItem.update()

    
            if ($recordChangedCounts.contains($newKey)) {
                $newCounts++
                $recordChangedCounts.Remove($newKey);
                $recordChangedCounts.Add($newKey, $newCounts)
           }
           else {
                $newCounts = 1
                $recordChangedCounts.Add($newKey, $newCounts)
           }

        }
       
    } else {
        foreach($oldItem in $facilityLookupItems) {
	        $oldItem["Application Status"] = $applicationStatusField
	        $oldItem["Study Title"] = $applicationStudyTitleField
	        $oldItem["ApplicationRecordID"] = $idField
	        $oldItem["Study_ID"] = $studyIDField
	        $oldItem["Title"] = $applicationTitleField
            $oldItem.update()

          
         
           if ($recordChangedCounts.contains($updatedKey)) {
                $updatedCounts++
                $recordChangedCounts.Remove($updatedKey)
                $recordChangedCounts.Add($updatedKey, $updatedCounts)
           }
           else {
                $updatedCounts = 1
                $recordChangedCounts.Add($updatedKey, $updatedCounts)
           }

           

        }
    }
    Write-Host "Migrated for: $scWeb" -foregroundcolor Green    
}

function OutputStatsToLog($startTime, $endTime) 
{

$time = Get-Date -Format "yyyyMMddHHmmss"


$filePath = "C:\temp\" + "MigrateFacilityData-" + $time + ".log"


$currentLine ="Start Time  $startTime End Time $endTime " 
Write-Output $currentLine | Out-File -FilePath $filepath -Append

$currentLine ="Summary Of Record Counts"
Write-Output $currentLine | Out-File -FilePath $filepath -Append
$recordCounts.GetEnumerator() | % { 
    $currentKey=$($_.key)
    $currentValue=$($_.value)
    $currentLine = "$currentKey Total Records=$currentValue"
    Write-Output $currentLine | Out-File -FilePath $filepath -Append

   
}

    $currentLine ="Summary Of New/Updated Records"
    Write-Output $currentLine | Out-File -FilePath $filepath -Append
    $recordChangedCounts.GetEnumerator() | % { 
        $currentKey=$($_.key)
        $updatedName = $currentKey.replace("-New"," New Records")
        $updatedName = $updatedName.replace("-Updated"," Updated Records")
        $currentValue=$($_.value)
        $currentLine = "$updatedName    $currentValue"
        Write-Output $currentLine | Out-File -FilePath $filepath -Append

   
    }
}

#This is to test the driver contains a $localSiteUrl
$startTime = Get-Date -Format "yyyyMMddHHmmss"
#$localSiteUrl="https://vaww.idev.ram.msp.va.gov/sites/IRBApplications/";
$w = Get-SPWeb $localSiteUrl
getAllFacilities $localSiteUrl
getRecordCounts $localSiteUrl
GetAllWebs $localSiteUrl
$endTime = Get-Date -Format "yyyyMMddHHmmss"
OutputStatsToLog $startTime $endTime
