Add-PSSnapin Microsoft.SharePoint.Powershell

$groupParts = @{
}

function  UpdateCommitteeList($web) 
{
 
    $list = $web.Lists.TryGetList("Committee List")
    if($list -ne $null)
    {
        #Get all items in this list and save them to a variable
        $items = $list.items

        #Go through all items
        foreach($item in $items)
        {

            $userfield = New-Object Microsoft.SharePoint.SPFieldUserValue($web,$item["Facility Users"].ToString());            
            
             <# 
	          The groupPart Logic to parse was failing when this ran for FacilityList. The work around was to map by the title which matches the Facility Name in 
	          Facility List. This allows the groups to be dynamically populated for the FacilityList.
          	#>
            $groupPart = $userfield.LookupValue.replace(" Users", "");
        
            $groupParts.Add($item["Title"], $groupPart)

    	    $iacucAdministratorsGroupName=($groupPart + " IACUC Administrators").Trim()
    		$iacucCoordinatorsGroupName=($groupPart + " IACUC Committee Coordinators").Trim()
    		$iacucMembersGroupName=($groupPart + " IACUC Committee Members").Trim()

            $item["IACUC Committee Administrators"] = $web.groups[$iacucAdministratorsGroupName]
            $item["IACUC Committee Coordinators"] = $web.groups[$iacucCoordinatorsGroupName]
			$item["IACUC Committee Members"] = $web.groups[$iacucMembersGroupName]

            $srsAdministratorsGroupName=($groupPart + " SRS Administrators").Trim()
    		$srsCoordinatorsGroupName=($groupPart + " SRS Committee Coordinators").Trim()
    		$srsMembersGroupName=($groupPart + " SRS Committee Members").Trim()
    
            $item["SRS Committee Administrators"] = $web.groups[$srsAdministratorsGroupName]
            $item["SRS Committee Coordinators"] = $web.groups[$srsCoordinatorsGroupName]
			$item["SRS Committee Members"] = $web.groups[$srsMembersGroupName]
         
            $irbAdministratorsGroupName=($groupPart + " IRB Administrators").Trim()
    		$irbCoordinatorsGroupName=($groupPart + " IRB Committee Coordinators").Trim()
    		$irbMembersGroupName=($groupPart + " IRB Committee Members").Trim()
    
         
            $item["IRB Committee Administrators"] = $web.groups[$irbAdministratorsGroupName]
            $item["IRB Committee Coordinators"] = $web.groups[$irbCoordinatorsGroupName]
			$item["IRB Committee Members"] = $web.groups[$irbMembersGroupName]
         
	        #Update the item
	        $item.Update()
    }
        write-host "Items in Committee List has been updated!" -f green
   }
}


function  UpdateFacilityList($web) 
{
    $list = $web.Lists.TryGetList("Facility")
    if($list -ne $null)
    {
        #Get all items in this list and save them to a variable
        $items = $list.items

        #Go through all items
        foreach($item in $items)
        {
    	    $facilityName=$item["Facility Name"]
            $groupPart = $groupParts[$facilityName];
            $iacucAdministratorsGroupName=($groupPart + " IACUC Administrators").Trim()
    		$iacucCoordinatorsGroupName=($groupPart + " IACUC Committee Coordinators").Trim()
    		$iacucMembersGroupName=($groupPart + " IACUC Committee Members").Trim()

            $item["IACUC Committee Administrators"] = $web.groups[$iacucAdministratorsGroupName]
            $item["IACUC Committee Coordinators"] = $web.groups[$iacucCoordinatorsGroupName]
			$item["IACUC Committee Members"] = $web.groups[$iacucMembersGroupName]

            $srsAdministratorsGroupName=($groupPart + " SRS Administrators").Trim()
    		$srsCoordinatorsGroupName=($groupPart + " SRS Committee Coordinators").Trim()
    		$srsMembersGroupName=($groupPart + " SRS Committee Members").Trim()
    
            $item["SRS Committee Administrators"] = $web.groups[$srsAdministratorsGroupName]
            $item["SRS Committee Coordinators"] = $web.groups[$srsCoordinatorsGroupName]
			$item["SRS Committee Members"] = $web.groups[$srsMembersGroupName]
         
            $irbAdministratorsGroupName=($groupPart + " IRB Administrators").Trim()
    		$irbCoordinatorsGroupName=($groupPart + " IRB Committee Coordinators").Trim()
    		$irbMembersGroupName=($groupPart + " IRB Committee Members").Trim()
    
            $item["IRB Committee Administrators"] = $web.groups[$irbAdministratorsGroupName]
            $item["IRB Committee Coordinators"] = $web.groups[$irbCoordinatorsGroupName]
			$item["IRB Committee Members"] = $web.groups[$irbMembersGroupName]
         
	        #Update the item
	        $item.Update()
    }
    write-host "Items in Facility List has been updated!" -f green
 }
}

function  UpdateCommitteeCT($web) 
{
    $field=$web.fields["IACUC Committee Administrators"];
	if ($field -ne $null) {
		$field.SelectionMode="PeopleAndGroups"
		$field.update($true)
	}
	
	$field=$web.fields["IACUC Committee Coordinators"];
	if ($field -ne $null) {
		$field.SelectionMode="PeopleAndGroups"
		$field.update($true)
	}
	
	$field=$web.fields["IACUC Committee Members"];
	if ($field -ne $null) {
		$field.SelectionMode="PeopleAndGroups"
		$field.update($true)
	}
	
	$field=$web.fields["IRB Committee Administrators"];
	if ($field -ne $null) {
		$field.SelectionMode="PeopleAndGroups"
		$field.update($true)
	}
	
	$field=$web.fields["IRB Committee Coordinators"];
	if ($field -ne $null) {
		$field.SelectionMode="PeopleAndGroups"
		$field.update($true)
	}
	
	$field=$web.fields["IRB Committee Members"];
	if ($field -ne $null) {
		$field.SelectionMode="PeopleAndGroups"
		$field.update($true)
	}
	
	$field=$web.fields["SRS Committee Administrators"];
	if ($field -ne $null) {
		$field.SelectionMode="PeopleAndGroups"
		$field.update($true)
	}
	
	$field=$web.fields["SRS Committee Coordinators"];
	
	if ($field -ne $null) {
		$field.SelectionMode="PeopleAndGroups"
		$field.update($true)
	}
	
	$field=$web.fields["SRS Committee Members"];
	
	if ($field -ne $null) {
		$field.SelectionMode="PeopleAndGroups"
		$field.update($true)
	}
	
	$field=$web.fields["IRBCommitteeMembers"];
	if ($field -ne $null) {
		$field.SelectionMode="PeopleAndGroups"
		$field.Title = "IRB Committee Members"
		$field.update($true)
	}
	
	$ct = $web.ContentTypes["Committee CT"];
	$ct.update($true);
    write-host "Committee CT has been updated!" -f green


}

#This is to test the driver contains a $siteUrl
#$siteUrl="https://vaww.idev.ram.msp.va.gov/sites/IRBApplications/";
$w = Get-SPWeb $siteUrl;
UpdateCommitteeCT($w)
UpdateCommitteeList($w)
UpdateFacilityList($w)